datastructuretools
==================

.. automodule:: abjad.tools.datastructuretools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedCollection.TypedCollection

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.ContextMap.ContextMap
      ~abjad.tools.datastructuretools.CyclicMatrix.CyclicMatrix
      ~abjad.tools.datastructuretools.CyclicPayloadTree.CyclicPayloadTree
      ~abjad.tools.datastructuretools.CyclicTuple.CyclicTuple
      ~abjad.tools.datastructuretools.Matrix.Matrix
      ~abjad.tools.datastructuretools.OrdinalConstant.OrdinalConstant
      ~abjad.tools.datastructuretools.PayloadTree.PayloadTree
      ~abjad.tools.datastructuretools.SortedCollection.SortedCollection
      ~abjad.tools.datastructuretools.StatalServer.StatalServer
      ~abjad.tools.datastructuretools.StatalServerCursor.StatalServerCursor
      ~abjad.tools.datastructuretools.TreeContainer.TreeContainer
      ~abjad.tools.datastructuretools.TreeNode.TreeNode
      ~abjad.tools.datastructuretools.TypedCounter.TypedCounter
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset
      ~abjad.tools.datastructuretools.TypedList.TypedList
      ~abjad.tools.datastructuretools.TypedOrderedDict.TypedOrderedDict
      ~abjad.tools.datastructuretools.TypedTuple.TypedTuple
